/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1
import Qt.labs.settings 1.0
import Bacon2D 1.0
import "pages"

MainView {
    id: mainView
    applicationName: "com.ubuntu.developer.andrew-hayzen.volleyball2d"
    automaticOrientation: true
    height: units.gu(40)
    objectName: "mainView"
    useDeprecatedToolbar: false
    width: units.gu(70)

    Settings {
        id: settings
        category: "settings"

        property bool aiDebugLayer: false
        property int highScore: -1
        property int motionDeadZone: 3
        property int targetScore: 5
        property bool useMotion: true
    }

    PageStack {
        id: mainPageStack

        property bool landscape: width > height

        onLandscapeChanged: {
            if (landscape && mainPageStack.currentPage === rotateScreenPage) {
                mainPageStack.pop()
            } else if (mainPageStack.currentPage !== rotateScreenPage) {
                mainPageStack.push(rotateScreenPage);
            }
        }

        GamePage {
            id: gamePage
        }

        SettingsPage {
            id: settingsPage
            objectName: "settingsPage"
        }

        RotateScreenPage {
            id: rotateScreenPage
        }

        Component.onCompleted: mainPageStack.push(gamePage)
    }
}
