/*
 * Copyright (C) 2014
 *      Andrew Hayzen <ahayzen@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.3
import Ubuntu.Components 1.1
import Bacon2D 1.0
import "../scenes"

Page {
    onVisibleChanged: {
        if (!visible && game.currentScene === gameScene) {
            gameScene.pause()
        }
    }

    Game {
        id: game
        currentScene: menuScene
        height: parent.height / scale
        scale: parent.width / width  // scale the scenes to meet the width
        transformOrigin: Qt.TopLeftCorner
        width: units.gu(70)
        x: 0
        y: 0

        MenuScene {
            id: menuScene
            objectName: "menuScene"
            onStartGame: {
                game.currentScene = gameScene
                gameScene.restart()
            }
        }

        FinishScene {
            id: finishScene
            objectName: "finishScene"
            onFinishedComplete: game.currentScene = menuScene
        }

        GameScene {
            id: gameScene
            objectName: "gameScene"

            onGameFinished: {
                // Tell finish scene about the scores
                finishScene.computerScore = computer.score
                finishScene.humanScore = human.score

                // Save new time if it is faster
                if (human.score > computer.score &&
                        (time < settings.highScore || settings.highScore === -1)) {
                    settings.highScore = time
                    finishScene.newHighScore = true
                } else {
                    finishScene.newHighScore = false
                }

                // Switch to the finish scene
                game.currentScene = finishScene;
            }
        }
    }
}
